# Comece!

Bem-vindo ao Rapunzel, um ambiente de desenvolvimento moderno para Python e R. Aqui estão alguns atalhos de teclado úteis.

## Trabalhando com pastas e arquivos do projeto

- [`Ctrl+Shift+O`: Abrir pasta do projeto](opensesame://event.rapunzel_welcome_open_folders)
- [`Ctrl+O`: Abrir arquivo das pastas do projeto](opensesame://event.rapunzel_welcome_open_files)
- [`Ctrl+N`: Criar documento vazio](opensesame://event.ide_new_file)

## Fazendo as coisas rapidamente

- [`Ctrl+Shift+P`: Ativar paleta de comandos](opensesame://event.command_palette_activate)
- `Ctrl+R`: Pular para função ou classe

## Executando código

- `F5`: Executar projeto ou arquivo
- `F9`: Executar seleção, célula ou linha atual